# Changelog

## 2.0.0 (2023-04-11)

- 🚀 Release 2.0.0 ()

## 0.0.2 (2023-04-02)

- 🔖 0.0.2 ([6627c23](https://github.com/xFGhoul/py-presencedb/commit/6627c23d045e20d06a1ef1ab8ce21ca65387516f))
- 👷 Add Github Integrations ([79e467e](https://github.com/xFGhoul/py-presencedb/commit/79e467eb51dc24d4b074c4136bb07838d8c57f0c))
- ♻️ Minor Refactoring ([e048d3d](https://github.com/xFGhoul/py-presencedb/commit/e048d3d32df9efd60bbf38eeed65eaff478200dc))

## 1.0.0 (2022-08-04)

- [Release 1.0](https://github.com/xFGhoul/py-presencedb/commit/824f9cfcb2036780e50164363f0896e5120f72de)
